"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createPositioningClasses = exports.createPaddingClasses = exports.createMarginClasses = exports.createColorClasses = void 0;
var _Color = require("./Color.js");
/**
 * This function is responsible to create class auxiliary for text colors and backgrounds
 * it uses a recursion to get to all possible properties of the theme and extract
 * all the colors used there and generate classes based on the properties names.
 * @param {object | string} currentObject
 * @param {string} property
 */
const getColorProperties = (currentObject, property = '') => {
  if (typeof currentObject === 'string') {
    return `
    .text${property} {
      color: ${currentObject};
    }
    .bg${property} {
      background-color: ${currentObject};
    }
    .fill${property} {
      ${(0, _Color.getFilteredColor)(currentObject)}
    }
  `;
  } else {
    return Object.keys(currentObject).map(currentObjectKey => {
      return getColorProperties(currentObject[currentObjectKey], `${property}-${currentObjectKey}`);
    }).join('');
  }
};
/**
 * This function is responsible to create class auxiliary for text colours and backgrounds
 * and backgrounds using the theme itself.
 * @param {ThemeType} theme
 */
const createColorClasses = theme => {
  return getColorProperties(theme.colors);
};
/**
 * This function is responsible to create class auxiliary for spacings
 * @param {object | string} currentObject
 * @param {string} property
 */
exports.createColorClasses = createColorClasses;
const getSpacingProperties = (spacingObject, property = '', propertyLetter = '') => {
  return Object.keys(spacingObject).map(currentObjectKey => {
    const lowerCaseObjectKey = currentObjectKey.toLowerCase();
    const value = spacingObject[currentObjectKey];
    return `
      .${propertyLetter}t-${lowerCaseObjectKey} {
        ${property}-top: ${value};
      }

      .${propertyLetter}b-${lowerCaseObjectKey} {
        ${property}-bottom: ${value};
      }

      .${propertyLetter}l-${lowerCaseObjectKey} {
        ${property}-left: ${value};
      }

      .${propertyLetter}r-${lowerCaseObjectKey} {
        ${property}-right: ${value};
      }

      .${propertyLetter}-${lowerCaseObjectKey} {
        ${property}: ${value};
      }

      .${propertyLetter}h-${lowerCaseObjectKey} {
        ${property}-left: ${value};
        ${property}-right: ${value};
      }

      .${propertyLetter}v-${lowerCaseObjectKey} {
        ${property}-top: ${value};
        ${property}-bottom: ${value};
      }
    `;
  }).join('');
};
/**
 * This function is responsible to create class auxiliary for spacings using the theme itself.
 * @param {ThemeType} theme
 */
const createPaddingClasses = theme => {
  return getSpacingProperties(theme.tokens?.padding, 'padding', 'p');
};
/**
 * This function is responsible to create class auxiliary for spacings using the theme itself.
 * @param {ThemeType} theme
 */
exports.createPaddingClasses = createPaddingClasses;
const createMarginClasses = theme => {
  return getSpacingProperties(theme.tokens?.flexbox, 'margin', 'm');
};
exports.createMarginClasses = createMarginClasses;
const createPositioningClasses = () => {
  return `
    .flex { display: flex };
    .flex-grow { flex: 1 };
    .align-start { align-items: flex-start };
    .align-center { align-items: center };
    .align-right { align-items: flex-end };
    .justify-left { justify-content: flex-start };
    .justify-center { justify-content: center };
    .justify-right { justify-content: flex-end };
    .justify-between { justify-content: space-between };
    .justify-evenly { justify-content: space-evenly };
    .justify-arround { justify-content: space-arround };
  `;
};
exports.createPositioningClasses = createPositioningClasses;